Mesa (staging/20.1): driconf: Support selection by Vulkan applicationName.

GitLab Mirror gitlab-mirror at kemper.freedesktop.org
Wed Aug 19 00:40:26 UTC 2020


Module: Mesa
Branch: staging/20.1
Commit: 967c5964fb82906a609679392b4e70c26760e632
URL:    http://cgit.freedesktop.org/mesa/mesa/commit/?id=967c5964fb82906a609679392b4e70c26760e632

Author: Bas Nieuwenhuizen <bas at basnieuwenhuizen.nl>
Date:   Thu Jul 30 02:33:01 2020 +0200

driconf: Support selection by Vulkan applicationName.

This adds applicationName + version through like engineName.

Rationale: A game (World War Z) includes the store name in the
executable name, so has multiple executable names.

CC: <mesa-stable at lists.freedesktop.org>
Reviewed-by: Samuel Pitoiset <samuel.pitoiset at gmail.com>
Part-of: <https://gitlab.freedesktop.org/mesa/mesa/-/merge_requests/6120>
(cherry picked from commit a1d4721e21b4d386e242714acc414c6f7e1294eb)

---

 .pick_status.json                               |  2 +-
 src/amd/vulkan/radv_device.c                    | 10 +++++++++
 src/amd/vulkan/radv_private.h                   |  2 ++
 src/gallium/auxiliary/pipe-loader/pipe_loader.c |  2 +-
 src/gallium/targets/d3dadapter9/drm.c           |  2 +-
 src/intel/vulkan/anv_device.c                   |  2 ++
 src/loader/loader.c                             |  4 ++--
 src/mesa/drivers/dri/common/dri_util.c          |  2 +-
 src/mesa/drivers/dri/i915/intel_context.c       |  2 +-
 src/mesa/drivers/dri/i965/brw_context.c         |  2 +-
 src/mesa/drivers/dri/i965/intel_screen.c        |  2 +-
 src/mesa/drivers/dri/r200/r200_context.c        |  2 +-
 src/mesa/drivers/dri/radeon/radeon_context.c    |  2 +-
 src/util/00-mesa-defaults.conf                  |  6 +++--
 src/util/xmlconfig.c                            | 29 +++++++++++++++++++++++++
 src/util/xmlconfig.h                            |  3 ++-
 16 files changed, 60 insertions(+), 14 deletions(-)

diff --git a/.pick_status.json b/.pick_status.json
index 0621083e46e..01ba42ddca7 100644
--- a/.pick_status.json
+++ b/.pick_status.json
@@ -103,7 +103,7 @@
         "description": "driconf: Support selection by Vulkan applicationName.",
         "nominated": true,
         "nomination_type": 0,
-        "resolution": 0,
+        "resolution": 1,
         "master_sha": null,
         "because_sha": null
     },
diff --git a/src/amd/vulkan/radv_device.c b/src/amd/vulkan/radv_device.c
index 2c9fab9bec0..c01811e3e31 100644
--- a/src/amd/vulkan/radv_device.c
+++ b/src/amd/vulkan/radv_device.c
@@ -595,6 +595,8 @@ static void  radv_init_dri_options(struct radv_instance *instance)
 	driParseConfigFiles(&instance->dri_options,
 	                    &instance->available_dri_options,
 	                    0, "radv", NULL,
+	                    instance->applicationName,
+	                    instance->applicationVersion,
 	                    instance->engineName,
 	                    instance->engineVersion);
 }
@@ -619,9 +621,13 @@ VkResult radv_CreateInstance(
 
 	const char *engine_name = NULL;
 	uint32_t engine_version = 0;
+	const char *application_name = NULL;
+	uint32_t application_version = 0;
 	if (pCreateInfo->pApplicationInfo) {
 		engine_name = pCreateInfo->pApplicationInfo->pEngineName;
 		engine_version = pCreateInfo->pApplicationInfo->engineVersion;
+		application_name = pCreateInfo->pApplicationInfo->pApplicationName;
+		application_version = pCreateInfo->pApplicationInfo->applicationVersion;
 	}
 
 	instance = vk_zalloc2(&default_alloc, pAllocator, sizeof(*instance), 8,
@@ -726,6 +732,9 @@ VkResult radv_CreateInstance(
 	instance->engineName = vk_strdup(&instance->alloc, engine_name,
 					 VK_SYSTEM_ALLOCATION_SCOPE_INSTANCE);
 	instance->engineVersion = engine_version;
+	instance->applicationName = vk_strdup(&instance->alloc, application_name,
+					 VK_SYSTEM_ALLOCATION_SCOPE_INSTANCE);
+	instance->applicationVersion = application_version;
 
 	glsl_type_singleton_init_or_ref();
 
@@ -753,6 +762,7 @@ void radv_DestroyInstance(
 	}
 
 	vk_free(&instance->alloc, instance->engineName);
+	vk_free(&instance->alloc, instance->applicationName);
 
 	VG(VALGRIND_DESTROY_MEMPOOL(instance));
 
diff --git a/src/amd/vulkan/radv_private.h b/src/amd/vulkan/radv_private.h
index a54f0147fbc..80e8001d604 100644
--- a/src/amd/vulkan/radv_private.h
+++ b/src/amd/vulkan/radv_private.h
@@ -345,6 +345,8 @@ struct radv_instance {
 	int                                         physicalDeviceCount;
 	struct radv_physical_device                 physicalDevices[RADV_MAX_DRM_DEVICES];
 
+	char *                                      applicationName;
+	uint32_t                                    applicationVersion;
 	char *                                      engineName;
 	uint32_t                                    engineVersion;
 
diff --git a/src/gallium/auxiliary/pipe-loader/pipe_loader.c b/src/gallium/auxiliary/pipe-loader/pipe_loader.c
index e0fb249b6f0..96f28492123 100644
--- a/src/gallium/auxiliary/pipe-loader/pipe_loader.c
+++ b/src/gallium/auxiliary/pipe-loader/pipe_loader.c
@@ -99,7 +99,7 @@ pipe_loader_load_options(struct pipe_loader_device *dev)
 
    driParseOptionInfo(&dev->option_info, xml_options);
    driParseConfigFiles(&dev->option_cache, &dev->option_info, 0,
-                       dev->driver_name, NULL, NULL, 0);
+                       dev->driver_name, NULL, NULL, 0, NULL, 0);
 }
 
 char *
diff --git a/src/gallium/targets/d3dadapter9/drm.c b/src/gallium/targets/d3dadapter9/drm.c
index 819aa59468c..7945f0d9bcc 100644
--- a/src/gallium/targets/d3dadapter9/drm.c
+++ b/src/gallium/targets/d3dadapter9/drm.c
@@ -251,7 +251,7 @@ drm_create_adapter( int fd,
 
     driParseOptionInfo(&defaultInitOptions, __driConfigOptionsNine);
     driParseConfigFiles(&userInitOptions, &defaultInitOptions, 0,
-                        "nine", NULL, NULL, 0);
+                        "nine", NULL, NULL, 0, NULL, 0);
     if (driCheckOption(&userInitOptions, "throttle_value", DRI_INT)) {
         throttling_value_user = driQueryOptioni(&userInitOptions, "throttle_value");
         if (throttling_value_user == -1)
diff --git a/src/intel/vulkan/anv_device.c b/src/intel/vulkan/anv_device.c
index e0e53321521..2f4e75d99ff 100644
--- a/src/intel/vulkan/anv_device.c
+++ b/src/intel/vulkan/anv_device.c
@@ -763,6 +763,8 @@ VkResult anv_CreateInstance(
    driParseOptionInfo(&instance->available_dri_options, anv_dri_options_xml);
    driParseConfigFiles(&instance->dri_options, &instance->available_dri_options,
                        0, "anv", NULL,
+                       instance->app_info.app_name,
+                       instance->app_info.app_version,
                        instance->app_info.engine_name,
                        instance->app_info.engine_version);
 
diff --git a/src/loader/loader.c b/src/loader/loader.c
index 8548cbdfedb..b96d8c75ef0 100644
--- a/src/loader/loader.c
+++ b/src/loader/loader.c
@@ -195,7 +195,7 @@ static char *loader_get_dri_config_driver(int fd)
 
    driParseOptionInfo(&defaultInitOptions, __driConfigOptionsLoader);
    driParseConfigFiles(&userInitOptions, &defaultInitOptions, 0,
-                       "loader", kernel_driver, NULL, 0);
+                       "loader", kernel_driver, NULL, 0, NULL, 0);
    if (driCheckOption(&userInitOptions, "dri_driver", DRI_STRING)) {
       char *opt = driQueryOptionstr(&userInitOptions, "dri_driver");
       /* not an empty string */
@@ -217,7 +217,7 @@ static char *loader_get_dri_config_device_id(void)
 
    driParseOptionInfo(&defaultInitOptions, __driConfigOptionsLoader);
    driParseConfigFiles(&userInitOptions, &defaultInitOptions, 0,
-                       "loader", NULL, NULL, 0);
+                       "loader", NULL, NULL, 0, NULL, 0);
    if (driCheckOption(&userInitOptions, "device_id", DRI_STRING))
       prime = strdup(driQueryOptionstr(&userInitOptions, "device_id"));
    driDestroyOptionCache(&userInitOptions);
diff --git a/src/mesa/drivers/dri/common/dri_util.c b/src/mesa/drivers/dri/common/dri_util.c
index 7ff7bfa5482..e7edf557c9d 100644
--- a/src/mesa/drivers/dri/common/dri_util.c
+++ b/src/mesa/drivers/dri/common/dri_util.c
@@ -150,7 +150,7 @@ driCreateNewScreen2(int scrn, int fd,
     /* Option parsing before ->InitScreen(), as some options apply there. */
     driParseOptionInfo(&psp->optionInfo, __dri2ConfigOptions);
     driParseConfigFiles(&psp->optionCache, &psp->optionInfo, psp->myNum,
-                        "dri2", NULL, NULL, 0);
+                        "dri2", NULL, NULL, 0, NULL, 0);
 
     *driver_configs = psp->driver->InitScreen(psp);
     if (*driver_configs == NULL) {
diff --git a/src/mesa/drivers/dri/i915/intel_context.c b/src/mesa/drivers/dri/i915/intel_context.c
index 73165418dc5..060efeb3c12 100644
--- a/src/mesa/drivers/dri/i915/intel_context.c
+++ b/src/mesa/drivers/dri/i915/intel_context.c
@@ -445,7 +445,7 @@ intelInitContext(struct intel_context *intel,
 	  0, sizeof(ctx->TextureFormatSupported));
 
    driParseConfigFiles(&intel->optionCache, &intelScreen->optionCache,
-                       sPriv->myNum, "i915", NULL, NULL, 0);
+                       sPriv->myNum, "i915", NULL, NULL, 0, NULL, 0);
    intel->maxBatchSize = 4096;
 
    /* Estimate the size of the mappable aperture into the GTT.  There's an
diff --git a/src/mesa/drivers/dri/i965/brw_context.c b/src/mesa/drivers/dri/i965/brw_context.c
index c9fd56c547e..c83210fe520 100644
--- a/src/mesa/drivers/dri/i965/brw_context.c
+++ b/src/mesa/drivers/dri/i965/brw_context.c
@@ -871,7 +871,7 @@ brw_process_driconf_options(struct brw_context *brw)
    driOptionCache *options = &brw->optionCache;
    driParseConfigFiles(options, &brw->screen->optionCache,
                        brw->driContext->driScreenPriv->myNum,
-                       "i965", NULL, NULL, 0);
+                       "i965", NULL, NULL, 0, NULL, 0);
 
    if (INTEL_DEBUG & DEBUG_NO_HIZ) {
        brw->has_hiz = false;
diff --git a/src/mesa/drivers/dri/i965/intel_screen.c b/src/mesa/drivers/dri/i965/intel_screen.c
index 6d01e756956..9f7e112aee1 100644
--- a/src/mesa/drivers/dri/i965/intel_screen.c
+++ b/src/mesa/drivers/dri/i965/intel_screen.c
@@ -2555,7 +2555,7 @@ __DRIconfig **intelInitScreen2(__DRIscreen *dri_screen)
 
    driParseOptionInfo(&options, brw_config_options.xml);
    driParseConfigFiles(&screen->optionCache, &options, dri_screen->myNum,
-                       "i965", NULL, NULL, 0);
+                       "i965", NULL, NULL, 0, NULL, 0);
    driDestroyOptionCache(&options);
 
    screen->driScrnPriv = dri_screen;
diff --git a/src/mesa/drivers/dri/r200/r200_context.c b/src/mesa/drivers/dri/r200/r200_context.c
index f1c5e8f172b..374f19a5c42 100644
--- a/src/mesa/drivers/dri/r200/r200_context.c
+++ b/src/mesa/drivers/dri/r200/r200_context.c
@@ -216,7 +216,7 @@ GLboolean r200CreateContext( gl_api api,
     * the default textures.
     */
    driParseConfigFiles (&rmesa->radeon.optionCache, &screen->optionCache,
-			screen->driScreen->myNum, "r200", NULL, NULL, 0);
+			screen->driScreen->myNum, "r200", NULL, NULL, 0, NULL, 0);
    rmesa->radeon.initialMaxAnisotropy = driQueryOptionf(&rmesa->radeon.optionCache,
 							"def_max_anisotropy");
 
diff --git a/src/mesa/drivers/dri/radeon/radeon_context.c b/src/mesa/drivers/dri/radeon/radeon_context.c
index e05b8ba2ff6..13a60326916 100644
--- a/src/mesa/drivers/dri/radeon/radeon_context.c
+++ b/src/mesa/drivers/dri/radeon/radeon_context.c
@@ -182,7 +182,7 @@ r100CreateContext( gl_api api,
     * the default textures.
     */
    driParseConfigFiles (&rmesa->radeon.optionCache, &screen->optionCache,
-			screen->driScreen->myNum, "radeon", NULL, NULL, 0);
+			screen->driScreen->myNum, "radeon", NULL, NULL, 0, NULL, 0);
    rmesa->radeon.initialMaxAnisotropy = driQueryOptionf(&rmesa->radeon.optionCache,
                                                  "def_max_anisotropy");
 
diff --git a/src/util/00-mesa-defaults.conf b/src/util/00-mesa-defaults.conf
index e02d4dc9d35..068d782cbfc 100644
--- a/src/util/00-mesa-defaults.conf
+++ b/src/util/00-mesa-defaults.conf
@@ -34,8 +34,10 @@ TODO: document the other workarounds.
    <!ATTLIST device       driver CDATA #IMPLIED>
    <!ELEMENT application  (option+)>
    <!ATTLIST application  name CDATA #REQUIRED
-                          executable CDATA #REQUIRED
-                          sha1 CDATA #IMPLIED>
+                          executable CDATA #IMPLIED
+                          sha1 CDATA #IMPLIED
+                          application_name_match CDATA #IMPLIED
+                          application_versions CDATA #IMPLIED>
    <!ELEMENT engine       (option+)>
 
    <!-- engine_name_match: A regexp matching the engine name -->
diff --git a/src/util/xmlconfig.c b/src/util/xmlconfig.c
index 4ddad79e8bd..a02e47e0ae5 100644
--- a/src/util/xmlconfig.c
+++ b/src/util/xmlconfig.c
@@ -715,7 +715,9 @@ struct OptConfData {
     const char *driverName, *execName;
     const char *kernelDriverName;
     const char *engineName;
+    const char *applicationName;
     uint32_t engineVersion;
+    uint32_t applicationVersion;
     uint32_t ignoringDevice;
     uint32_t ignoringApp;
     uint32_t inDriConf;
@@ -782,10 +784,20 @@ parseAppAttr(struct OptConfData *data, const XML_Char **attr)
     uint32_t i;
     const XML_Char *exec = NULL;
     const XML_Char *sha1 = NULL;
+    const XML_Char *application_name_match = NULL;
+    const XML_Char *application_versions = NULL;
+    driOptionInfo version_ranges = {
+       .type = DRI_INT,
+    };
+
     for (i = 0; attr[i]; i += 2) {
         if (!strcmp (attr[i], "name")) /* not needed here */;
         else if (!strcmp (attr[i], "executable")) exec = attr[i+1];
         else if (!strcmp (attr[i], "sha1")) sha1 = attr[i+1];
+        else if (!strcmp (attr[i], "application_name_match"))
+           application_name_match = attr[i+1];
+        else if (!strcmp (attr[i], "application_versions"))
+           application_versions = attr[i+1];
         else XML_WARNING("unknown application attribute: %s.", attr[i]);
     }
     if (exec && strcmp (exec, data->execName)) {
@@ -814,6 +826,20 @@ parseAppAttr(struct OptConfData *data, const XML_Char **attr)
                 data->ignoringApp = data->inApp;
             }
         }
+    } else if (application_name_match) {
+       regex_t re;
+
+       if (regcomp (&re, application_name_match, REG_EXTENDED|REG_NOSUB) == 0) {
+          if (regexec (&re, data->applicationName, 0, NULL, 0) == REG_NOMATCH)
+             data->ignoringApp = data->inApp;
+          regfree (&re);
+       } else
+          XML_WARNING ("Invalid application_name_match=\"%s\".", application_name_match);
+    }
+    if (application_versions) {
+       if (parseRanges (&version_ranges, application_versions) &&
+           !valueInRanges (&version_ranges, data->applicationVersion))
+          data->ignoringApp = data->inApp;
     }
 }
 
@@ -1103,6 +1129,7 @@ void
 driParseConfigFiles(driOptionCache *cache, const driOptionCache *info,
                     int screenNum, const char *driverName,
                     const char *kernelDriverName,
+                    const char *applicationName, uint32_t applicationVersion,
                     const char *engineName, uint32_t engineVersion)
 {
     char *home;
@@ -1114,6 +1141,8 @@ driParseConfigFiles(driOptionCache *cache, const driOptionCache *info,
     userData.screenNum = screenNum;
     userData.driverName = driverName;
     userData.kernelDriverName = kernelDriverName;
+    userData.applicationName = applicationName ? applicationName : "";
+    userData.applicationVersion = applicationVersion;
     userData.engineName = engineName ? engineName : "";
     userData.engineVersion = engineVersion;
     userData.execName = util_get_process_name();
diff --git a/src/util/xmlconfig.h b/src/util/xmlconfig.h
index 6cc3e8b59d7..3ecd5188634 100644
--- a/src/util/xmlconfig.h
+++ b/src/util/xmlconfig.h
@@ -104,10 +104,11 @@ void driParseOptionInfo (driOptionCache *info,
 /** \brief Initialize option cache from info and parse configuration files
  *
  * To be called in <driver>CreateContext. screenNum, driverName,
  * kernelDriverName and engineName select device sections. */
 void driParseConfigFiles (driOptionCache *cache, const driOptionCache *info,
 			  int screenNum, const char *driverName,
 			  const char *kernelDriverName,
+			  const char *applicationName, uint32_t applicationVersion,
 			  const char *engineName, uint32_t engineVersion);
 /** \brief Destroy option info
  *
@@ -104,10 +104,11 @@ void driParseOptionInfo (driOptionCache *info,
  *
  * To be called in <driver>CreateContext. screenNum, driverName,
- * kernelDriverName and engineName select device sections. */
+ * kernelDriverName, applicationName and engineName select device sections. */
 void driParseConfigFiles (driOptionCache *cache, const driOptionCache *info,
 			  int screenNum, const char *driverName,



More information about the mesa-commit mailing list